@@ -1,6 +1,4 @@
-/* -*- mode: c++; c-basic-offset:4 -*-
-    exportcertificatecommand.cpp
-
+/*
     This file is part of Kleopatra, the KDE keymanager
     SPDX-FileCopyrightText: 2007 Klarälvdalens Datakonsult AB
     SPDX-FileCopyrightText: 2021 g10 Code GmbH
@@ -11,7 +9,7 @@
 #include <config-kleopatra.h>
 
 #include "exportcertificatecommand.h"
-#include "fileoperationspreferences.h"
+#include <settings.h>
 
 #include "command_p.h"
 
@@ -232,7 +230,7 @@ bool ExportCertificateCommand::Private::requestFileNames(GpgME::Protocol protoco
 
     QString proposedFileName = lastDir + QLatin1Char('/');
     if (keys().size() == 1) {
-        const bool usePGPFileExt = FileOperationsPreferences().usePGPFileExt();
+        const bool usePGPFileExt = Settings().usePGPFileExt();
         const auto key = keys().front();
         auto name = Formatting::prettyName(key);
         if (name.isEmpty()) {
